import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.*;

public class HamletParserTest {
    private String hamletText;
    private HamletParser hamletParser;

    @Before
    public void setUp() {
        this.hamletParser = new HamletParser();
        this.hamletText = hamletParser.getHamletData();
    }

    @Test
    public void testChangeHamletToLeon() {
        String testString = "Hamlet is a really terrible story.";
        String acutal = hamletParser.swapWords(testString, "Hamlet", "Leon");
        String expect = "Leon is a really terrible story.";

        Assert.assertEquals(expect, acutal);
    }

    @Test
    public void findPunctuation(){
        String testString = "Hamlet.";
        String expect = ".";
        String actual = hamletParser.findPunctuation(testString);

        Assert.assertEquals(expect, actual);
    }

    @Test
    public void testChangeHoratioToTariq() {
        String testString = "Horatio is a persons name?";
        String acutal = hamletParser.swapWords(testString, "Horatio", "Tariq");
        String expect = "Tariq is a persons name?";

        Assert.assertEquals(expect, acutal);
    }

    @Test
    public void testFindHoratio() {
        String testString = "Horatio is a persons name?";
        boolean acutal = hamletParser.findName(testString,"Horatio");
        boolean expect = true;

        Assert.assertEquals(expect, acutal);
    }

    @Test
    public void testFindHamlet() {
        String testString = "Hamlet is a persons name?";
        boolean acutal = hamletParser.findName(testString,"Hamlet");
        boolean expect = true;

        Assert.assertEquals(expect, acutal);
    }

    @Test
    public void testFindHoratioFail() {
        String testString = "Hamlet is a persons name?";
        boolean actual = hamletParser.findName(testString,"Horatio");
        Assert.assertFalse(actual);
    }

    @Test
    public void testFindHamletFail() {
        String testString = "Horatio is a persons name?";
        boolean actual = hamletParser.findName(testString,"Hamlet");

        Assert.assertFalse(actual);
    }
}